#
# Configuration file for creating GNOME panel applets
#
APPLETS_LIBDIR="-Wl,-E -L/usr/X11R6/lib -L/usr/local/lib"
APPLETS_LIBS="-lpanel_applet -Wl,-E -lgnorba -lORBitCosNaming -lORBit -lIIOP -lORBitutil -lwrap -lXpm -ljpeg -lgnomeui -lart_lgpl -lgdk_imlib -ltiff -lungif -lpng -lz -lSM -lICE -lgtk12 -lgdk12 -lgmodule12 -lXext -lX11 -lgnome -lgnomesupport -lintl -lesd -lgnugetopt -laudiofile -lm -lglib12"
APPLETS_INCLUDEDIR="-I/usr/X11R6/include/gnome-1.0 -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/X11R6/lib/gnome-libs/include -I/usr/local/include/glib12 -I/usr/local/include/orbit-1.0 -I/usr/local/include -I/usr/X11R6/include/gtk12 -I/usr/X11R6/include/libcapplet1 -I/usr/X11R6/include/gnome-1.0 -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/X11R6/lib/gnome-libs/include -I/usr/local/include/glib12 -I/usr/local/include/orbit-1.0 -I/usr/local/include -I/usr/X11R6/include/gtk12"
MODULE_VERSION="applets-1.4.1"
